

#include <ADuC7026.h>

char hex2ascii(char toconv);

// initialize uart
void usart_init(void)
{
	// Setup rx and tx pins on P1.0 and P1.1
	GP1CON |= 0x011;
	
	// Start setting up UART at 115200bps
	COMCON0 = 0x80;				// Setting DLAB
	COMDIV0 = 0x0B;            	// setting for 115200 bps  DIV = 11
	COMDIV1 = 0x00;
	COMCON0 = 0x03;				// Clearing DLAB (8 bits, No parity, 1 stop bit) 8-N-1 
	COMDIV2 = 0x883E;          	// M = 1 N = 62	(use fractional baud divide register to reduce error)
}

// write a byte
void usart_tx_byte(char data)
{
  	while(!(COMSTA0 & 0x020));       	// TX buffer ready?
 	COMTX = data;						// transmit byte
}

// write an array of bytes
void usart_tx_bytes(char * data, unsigned char length)
{
	unsigned char i = 0;
	
	for(i = 0; i < length; i++)
	{
  		while(!(COMSTA0 & 0x020));      // TX buffer ready?
 		COMTX = data[i];				// transmit byte        
  	}
}

// write an integer sending the MSB last since this is how Matlab interprets an integer using fread()
void usart_tx_int(short int data)
{
  
  while(!(COMSTA0 & 0x020));       		// TX buffer ready?
  COMTX = (char)data;         	   		// transmit LSB 
  
  while(!(COMSTA0 & 0x020));       		// TX buffer ready?
  COMTX = (char)(data >> 8);       		// transmit MSB
  
}

// write an array of integers
void usart_tx_ints(short int * data, short unsigned int length)
{
	short unsigned int i = 0;
	  
	for(i = 0; i < length; i++)
	{
		while(!(COMSTA0 & 0x020));       		 // TX buffer ready?
		COMTX = (unsigned char)data[i];          // transmit LSB 
		  
		while(!(COMSTA0 & 0x020));       		 // TX buffer ready?
		COMTX = (unsigned char)(data[i] >> 8);   // transmit MSB 
	}
  
}

void usart_tx_hex_int(short data)
{
	usart_tx_byte('0');   	
	usart_tx_byte('x');
	usart_tx_byte(hex2ascii((data >> 12) & 0x0F));   	
	usart_tx_byte(hex2ascii((data >> 8) & 0x0F));
    usart_tx_byte(hex2ascii((data >> 4) & 0x0F));
	usart_tx_byte(hex2ascii(data & 0x0F));
}

void serial_send_reg(unsigned char address, short data)
{
	// send address in hex
	usart_tx_byte('0');   	
	usart_tx_byte('x');		
	usart_tx_byte(hex2ascii((address >> 4) & 0x0F));   	
	usart_tx_byte(hex2ascii(address & 0x0F));

	usart_tx_byte(':');					// add a tab	
	usart_tx_byte(' ');					// add a tab	

	// send value in hex
	usart_tx_byte('0');   	
	usart_tx_byte('x');
	usart_tx_byte(hex2ascii((data >> 12) & 0x0F));   	
	usart_tx_byte(hex2ascii((data >> 8) & 0x0F));
    usart_tx_byte(hex2ascii((data >> 4) & 0x0F));
	usart_tx_byte(hex2ascii(data & 0x0F));

	// break to new line
	usart_tx_byte('\n');					// output LF
    usart_tx_byte('\r');					// output CR
							
}

char hex2ascii(char toconv)
{
	if (toconv<0x0A) 
	{
		toconv += 0x30;
	}
	else 
	{
		toconv += 0x37;
	}
	
	return (toconv);
}


