/*********************************************************************

 Author        : Carey Merritt

 Date          : July 2011

 File          : reg_def.h

 Hardware      : 
                  
 Description   : Defined registers of the ADIS16227 

 Rev			Date			Changes
 1.0			
*********************************************************************/

// -------------- ADIS16227 Buffers --------------------------------//

// Define Three Data Buffers
short int X_DATA[512]; 		   	// 16 bit
short int Y_DATA[512]; 		   	// 16 bit
short int Z_DATA[512]; 		   	// 16 bit

// Define Three FFT Average Buffers (accumulate FFTs)
unsigned short X_FFT[256]; 		// 16 bit
unsigned short Y_FFT[256]; 		// 16 bit
unsigned short Z_FFT[256];		// 16 bit

// -------------- ADIS16227 User Registers -------------------------//
struct user_regs
{	
	unsigned short ENDURANCE; 		// 0x00 Diagnostics, flash write counter (16-bit binary)
	short int X_NULL; 				// 0x02 Calibration, x-axis acceleration offset null
	short int Y_NULL;				// 0x04 Calibration, y-axis acceleration offset null
	short int Z_NULL;				// 0x06 Calibration, z-axis acceleration offset null
	
	unsigned short REC_FLSH_CNT;	// 0x08 Diagnostics, record flash write counter (16-bit binary)
	short int SUPPLY_OUT;			// 0x0A Output, power supply
	short int TEMP_OUT;				// 0x0C Output, temperature
	unsigned short FFT_AVG;			// 0x0E Operation, FFT average size
	unsigned short BUF_PNTR;		// 0x10 Operation, buffer address pointer
	unsigned short REC_PNTR;		// 0x12 Operation, record address pointer (accessing flash memory)
	short int X_BUF;				// 0x14 Output, x-axis buffer (from X_FFT[i])
	short int Y_BUF;				// 0x16 Output, y-axis buffer (from Y_FFT[i])
	short int Z_BUF;				// 0x18 Output, z-axis buffer (from Z_FFT[i])
	unsigned short REC_CNT;			// 0x1A Output, record number total
	unsigned short REC_CTRL;		// 0x1C Operation, record control register
	unsigned short REC_PRD;			// 0x1E Operation, record period register (automatic mode only)

	unsigned short ALM_F_LOW;		// 0x20 Spectral Alarm Band, Lower Frequency of alarm band
 	unsigned short ALM_F_HIGH;		// 0x22 Spectral Alarm Band, Higher Frequency of alarm band
	unsigned short ALM_X_MAG1;		// 0x24 Spectral Alarm Band, X-Axis Alarm 1 Magnitude
	unsigned short ALM_Y_MAG1;		// 0x26 Spectral Alarm Band, Y-Axis Alarm 1 Magnitude
	unsigned short ALM_Z_MAG1;		// 0x28 Spectral Alarm Band, Z-Axis Alarm 1 Magnitude
	unsigned short ALM_X_MAG2;		// 0x24 Spectral Alarm Band, X-Axis Alarm 2 Magnitude
	unsigned short ALM_Y_MAG2;		// 0x26 Spectral Alarm Band, Y-Axis Alarm 2 Magnitude
	unsigned short ALM_Z_MAG2;		// 0x28 Spectral Alarm Band, Z-Axis Alarm 2 Magnitude
	unsigned short ALM_PNTR;		// 0x30 Spectral Alarm Band, Pointer (writing to flash)		
	short int ALM_S_MAG;			// 0x32 Alarm, control register
	unsigned short ALM_CTRL;		// 0x34 Operation, general purpose I/O configuration
	unsigned short DIO_CTRL;		// 0x36 Operation, digital I/O configuration
	unsigned short GPIO_CTRL;		// 0x38 Operation, general purpose I/O configuration
	unsigned char dummy0[2];		// 0x3A reserved - 2 bytes
	unsigned short STATUS;	 		// 0x3C Diagnostics, system status register
	unsigned short COMMAND;			// 0x3E Operation, system command register

	unsigned short ALM_X_STAT;		// 0x40 Info, X-Axis alarm band and frequency bin that contains largest peak value to set off alarm
	unsigned short ALM_Y_STAT;		// 0x42 Info, Y-Axis alarm band and frequency bin that contains largest peak value to set off alarm
	unsigned short ALM_Z_STAT;		// 0x44 Info, Z-Axis alarm band and frequency bin that contains largest peak value to set off alarm
	unsigned short ALM_X_PEAK;		// 0x46 Info, X-Axis Peak for most severe alarm (largest delta)
	unsigned short ALM_Y_PEAK;		// 0x48 Info, Y-Axis Peak for most severe alarm (largest delta)
	unsigned short ALM_Z_PEAK;		// 0x4A Info, Z-Axis Peak for most severe alarm (largest delta)	
	unsigned long TIME_STAMP;		// 32 bit time stamp, in seconds	
	unsigned char dummy1[2];		// reserved		
	unsigned char REV;				// 0x52 Software revision (2 digit hex)				
	unsigned char DATE;				// 0x53 Data Code Day value (2 digit hex)
	unsigned char MONTH;			// 0x54 Data Code Month value (2 digit hex)
	unsigned char YEAR;				// 0x55 Data Code Year value (2 digit hex)
	unsigned short PROD_ID;			// 0x56 Product Identifier - '16227'
	short int SCRATCH_A;			// 0x58 Scratch register A - gen. purpose
	short int SCRATCH_B;			// 0x5A Scratch register B - gen. purpose		
	unsigned char dummy2[20];		// reserved
	unsigned short ALM_X_FREQ;		// 0x70 Info, X-Axis Frequency for most severe alarm (largest delta)	
	unsigned short ALM_Y_FREQ;		// 0x72 Info, Y-Axis Frequency for most severe alarm (largest delta)	
	unsigned short ALM_Z_FREQ;		// 0x74 Info, Z-Axis Frequency for most severe alarm (largest delta)	
	unsigned short REC_INFO;		// 0x76 Sample rate, fft averages, window option, range for current record
};

volatile struct user_regs REG;
